#[repr(u32)]pub enum KeymapId {
UsQwerty = 0,
FrAzerty = 1,
UsDvorak = 2,
UsColemak = 3,
UnknownOrdinal_(u32),
}Expand description
Keymaps that should always be present and selectable. The fallback keymaps may be useful on their own but are mainly here to ensure that at least some keymap is present if no other custom keymaps have been defined or in use.
Variants